@@ -1,5 +1,6 @@
 // Copyright (C) 2019 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:critical reason:data-parser
 
 #include "qwebphandler_p.h"
 #include "webp/mux.h"
@@ -13,6 +14,8 @@
 
 static const int riffHeaderSize = 12; // RIFF_HEADER_SIZE from webp/format_constants.h
 
+QT_BEGIN_NAMESPACE
+
 QWebpHandler::QWebpHandler() :
     m_quality(75),
     m_scanState(ScanNotScanned),
@@ -394,3 +397,5 @@ int QWebpHandler::nextImageDelay() const
 
     return m_iter.duration;
 }
+
+QT_END_NAMESPACE
